@@ -180,6 +180,13 @@ int ipkg_conf_init(ipkg_conf_t *conf, const args_t *args)
         sprintf (lists_dir,"%s",IPKG_CONF_LISTS_DIR);
      }
 
+     if (args->offline_root) {
+            char *tmp = malloc(strlen(lists_dir) + strlen(args->offline_root) + 1);
+            sprintf_alloc(&tmp, "%s/%s",args->offline_root,lists_dir);
+            free(lists_dir);
+            lists_dir = tmp;
+     }
+
      pending_dir = malloc(strlen(lists_dir)+strlen("/pending")+5);
      snprintf(pending_dir,strlen(lists_dir)+strlen("/pending") ,"%s%s",lists_dir,"/pending");
 
@@ -276,7 +283,8 @@ int ipkg_conf_init(ipkg_conf_t *conf, const args_t *args)
 */
      if ( !(args->nocheckfordirorfile)){
         /* need to run load the source list before dest list -Jamey */
-        set_and_load_pkg_src_list(conf, &conf->pkg_src_list);
+        if ( !(args->noreadfeedsfile))
+           set_and_load_pkg_src_list(conf, &conf->pkg_src_list);
    
         /* Now that we have resolved conf->offline_root, we can commit to
 	   the directory names for the dests and load in all the package
