@@ -19,13 +19,11 @@
 #include "ipkg.h"
 #include "ipkg_install.h"
 #include "ipkg_message.h"
-#include "ipkg_remove.h"
 
 int ipkg_upgrade_pkg(ipkg_conf_t *conf, pkg_t *old)
 {
      pkg_t *new;
      int cmp;
-     int err;
      char *old_version, *new_version;
 
      if (old->state_flag & SF_HOLD) {
@@ -75,14 +73,5 @@ int ipkg_upgrade_pkg(ipkg_conf_t *conf, pkg_t *old)
      }
 
      new->state_flag |= SF_USER;
-/* We should remove the old package, before installing the new one.
-   We would leave the depends: one there, as it could break other packages. */
-/* BTW I think we shouldn't remove the "essential" ones */
-     old->state_flag |= SF_REPLACE;
-     err = ipkg_remove_pkg(conf, old,1);                                    
-     if (err==IPKG_PKG_IS_ESSENTIAL) {
-           return err;
-     }
-/* and now we install the new one */
      return ipkg_install_pkg(conf, new,1);
 }
