@@ -174,7 +174,13 @@ int pkg_hash_fetch_unsatisfied_dependencies(ipkg_conf_t *conf, pkg_t * pkg,
 		    pkg_hash_fetch_best_installation_candidate(conf, satisfying_apkg, 
 							       pkg_installed_and_constraint_satisfied, 
 							       dependence_to_satisfy, 1);
-	       ipkg_message(conf, IPKG_DEBUG, "%s:%d: satisfying_pkg=%p\n", __FILE__, __LINE__, satisfying_pkg);
+               /* Being that I can't test constraing in pkg_hash, I will test it here */
+	       if (satisfying_pkg != NULL) {
+                  if (!pkg_installed_and_constraint_satisfied ( satisfying_pkg,dependence_to_satisfy)) {
+	              satisfying_pkg = NULL;
+                  }
+               }
+	       ipkg_message(conf, IPKG_DEBUG, "%s:%d: satisfying_pkg=%p \n", __FILE__, __LINE__, satisfying_pkg);
 	       if (satisfying_pkg != NULL) {
 		    found = 1;
 		    break;
@@ -192,6 +198,12 @@ int pkg_hash_fetch_unsatisfied_dependencies(ipkg_conf_t *conf, pkg_t * pkg,
 			 pkg_hash_fetch_best_installation_candidate(conf, satisfying_apkg, 
 								    pkg_constraint_satisfied, 
 								    dependence_to_satisfy, 1);
+                    /* Being that I can't test constraing in pkg_hash, I will test it here too */
+	            if (satisfying_pkg != NULL) {
+                         if (!pkg_constraint_satisfied ( satisfying_pkg,dependence_to_satisfy)) {
+                            satisfying_pkg = NULL;
+                         }
+                    }
 
 		    /* user request overrides package recommendation */
 		    if (satisfying_pkg != NULL
@@ -263,8 +275,10 @@ int is_pkg_a_replaces(pkg_t *pkg_scout,pkg_t *pkg)
     replaces = pkg->replaces;
 
     for (i = 0; i < replaces_count; i++) {
-        if (strcmp(pkg_scout->name,pkg->replaces[i]->name)==0)       // Found
+        if (strcmp(pkg_scout->name,pkg->replaces[i]->name)==0) {      // Found
+            ipkg_message(NULL, IPKG_DEBUG2, "Seems I've found a replace %s %s \n",pkg_scout->name,pkg->replaces[i]->name);
             return 1;
+        }
     }
     return 0;
 
@@ -494,13 +508,15 @@ int pkg_replaces(pkg_t *pkg, pkg_t *replacee)
 {
      abstract_pkg_t **replaces = pkg->replaces;
      int replaces_count = pkg->replaces_count;
-     abstract_pkg_t **replacee_provides = pkg->provides;
-     int replacee_provides_count = pkg->provides_count;
+     /* abstract_pkg_t **replacee_provides = pkg->provides;
+     int replacee_provides_count = pkg->provides_count; */
      int i, j;
      for (i = 0; i < replaces_count; i++) {
 	  abstract_pkg_t *abstract_replacee = replaces[i];
-	  for (j = 0; j < replacee_provides_count; j++) {
-	       if (replacee_provides[j] == abstract_replacee)
+	  for (j = 0; j < replaces_count; j++) {
+   /*            ipkg_message(NULL, IPKG_DEBUG2, "Searching pkg-name %s repprovname %s absrepname %s \n",
+                 pkg->name,replacee->provides[j]->name, abstract_replacee->name); */
+	       if (replacee->provides[j] == abstract_replacee)
 		    return 1;
 	  }
      }
